@@ -16,7 +16,7 @@ class AllHentaiRu(Provider, Std):
         return self._get_content('{}/{}?mature=1&mtr=1')
 
     def get_manga_name(self) -> str:
-        return self._get_name(r'\.ru/([^/]+)')
+        return self._get_name(r'\.\w{2,7}/([^/]+)')
 
     def get_chapters(self):
         return self._elements('.expandable .cTable tr > td > a')
