@@ -4,10 +4,6 @@ from .helpers.std import Std
 
 class ReadEgScansCom(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('-')
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         idx = self.re.search(r'/Chapter_(\d+)(.*)', self.chapter)
         return self._join_groups(idx.groups())
