@@ -1,22 +1,23 @@
 from manga_py.provider import Provider
 from .helpers.std import Std
+from re import compile
 
 
 class ReadMngCom(Provider, Std):
+    _re = compile(r'\.\w{2,7}/[^/]+/(\d+(?:\.\d+)?)/?')
 
     def get_chapter_index(self) -> str:
         ch = self.chapter
-        re = r'\.com/[^/]+/(\d+(?:\.\d+)?)/?'
-        idx = self.re.search(re, ch)
+        idx = self._re.search(ch)
         if not idx:
-            return self.re.search(r'\.com/[^/]+/([^/]+)', ch).group(1)
+            return self.re.search(r'\.\w{2,7}/[^/]+/([^/]+)', ch).group(1)
         return '-'.join(idx.group(1).split('.'))
 
     def get_main_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
-        return self._get_name(r'\.com/([^/]+)')
+        return self._get_name(r'\.\w{2,7}/([^/]+)')
 
     def get_chapters(self):
         return self._elements('.chp_lst li > a')
